yakumo.keystone.v2.service

Package yakumo :: Package keystone :: Package v2 :: Module service |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.keystone.v2.service

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for services in Identity V2 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23
    24
    25  ATTRIBUTE_MAPPING = [
    26      ('id', 'id', mapper.Noop),
    27      ('name', 'name', mapper.Noop),
    28      ('type', 'type', mapper.Noop),
    29      ('description', 'description', mapper.Noop),
    30      ('is_enabled', 'enabled', mapper.Noop),
    31  ]
    32
    33
    34 -class Resource(base.Resource):
    35      """resource class for services on Identity V2 API"""
    36
    37
    38 -class Manager(base.Manager):
    39      """manager class for services on Identity V2 API"""
    40
    41      resource_class = Resource
    42      service_type = 'identity'
    43      _attr_mapping = ATTRIBUTE_MAPPING
    44      _hidden_methods = ["update"]
    45      _json_resource_key = 'OS-KSADM:service'
    46      _json_resources_key = 'OS-KSADM:services'
    47      _url_resource_path = '/OS-KSADM/services'
    48
    49 -    def create(self, name=UNDEF, type=UNDEF, description=UNDEF,
    50                 is_enabled=UNDEF):
    51          """
    52          Register a service
    53
    54          @keyword name: Service name
    55          @type name: str
    56          @keyword type: Service type
    57          @type type: str
    58          @keyword description: Description
    59          @type description: str
    60          @keyword is_enabled: Whether the service is enabled or not
    61          @type is_enabled: str
    62          @return: Created service
    63          @rtype: yakumo.keystone.v2.service.Resource
    64          """
    65          return super(Manager, self).create(
    66              name=name,
    67              type=type,
    68              description=description,
    69              is_enabled=is_enabled)
    70